@@ -1,9 +1,11 @@
 from neo4j import GraphDatabase
 import networkx as nx
+from networkx.exception import NetworkXError
 from dotenv import load_dotenv
 import os
 from datetime import date
 import pickle
+from colored import cprint
 load_dotenv()
 
 URI = os.getenv("NEO4J_URI")
@@ -39,7 +41,7 @@ class Neo4jGraphDatabase(BaseGraphDatabase):
     def __init__(self):
         try:
             self.driver = GraphDatabase.driver(URI, auth=(AUTH[0], AUTH[1]))
-            print("Successfully connected to Neo4j database.")
+            cprint("Successfully connected to Neo4j database.", "green")
         except Exception as e:
             print(f"Failed to connect to Neo4j database: {e}")
             self.driver = None
@@ -126,7 +128,7 @@ class Neo4jGraphDatabase(BaseGraphDatabase):
         }
 
         self._execute_query(query, parameters)
-        print(f"Successfully added/updated entity: {label} with {primary_key_field} = '{primary_value}'")
+        #print(f"Successfully added/updated entity: {label} with {primary_key_field} = '{primary_value}'")
 
     def add_relationship(self, start_node_label, start_pk_field, start_node_pk_val, end_node_label, end_pk_field, end_node_pk_val, relationship_type, properties=None, symmetric=False):
         """
@@ -178,7 +180,7 @@ class Neo4jGraphDatabase(BaseGraphDatabase):
             print(f"Error creating relationship: {e}")
             return False
         
-        print(f"Successfully created relationship: ({start_node_pk_val})-[{relationship_type}]->({end_node_pk_val})")
+        #print(f"Successfully created relationship: ({start_node_pk_val})-[{relationship_type}]->({end_node_pk_val})")
 
     def _get_primary_key_field(self, label):
         """
@@ -352,6 +354,9 @@ class NetworkxGraphDatabase(BaseGraphDatabase):
                 self.graph = pickle.load(f)
         except FileNotFoundError:
             pass
+        num_nodes = self.graph.number_of_nodes()
+        num_edges = self.graph.number_of_edges()
+        cprint(f"Successfully initialized Networkx database with {num_nodes} nodes, {num_edges} relationships.", "green")
 
     def add_or_update_entity(self, label, primary_key_field, properties):
         if primary_key_field not in properties:
@@ -376,30 +381,39 @@ class NetworkxGraphDatabase(BaseGraphDatabase):
             self.graph.add_edge(end_node_pk_val, start_node_pk_val, **edge_properties)
 
     def get_all_entities_by_label(self, label):
-        return [data for node, data in self.graph.nodes(data=True) if data.get('label') == label]
+        if self.graph.has_node(label):
+            return [data for node, data in self.graph.nodes(data=True) if data.get('label') == label]
+        else:
+            return []
 
     def get_relationship_entities(self, domain_label, domain_pk_prop, domain_primary_key_value, relationship_type, range_label, range_primary_key_prop):
         # This is a simplified implementation. A more robust version would check labels and properties.
-        return [self.graph.nodes[neighbor] for neighbor in self.graph.successors(domain_primary_key_value)]
+        if self.graph.has_node(domain_primary_key_value):
+            return [self.graph.nodes[neighbor] for neighbor in self.graph.successors(domain_primary_key_value)]
+        else:
+            return []
 
     def get_relationship_properties(self, domain_label, domain_pk_prop, domain_primary_key_value, relationship_type, range_label, range_pk_prop, range_primary_key_value):
         if self.graph.has_edge(domain_primary_key_value, range_primary_key_value):
             return self.graph.get_edge_data(domain_primary_key_value, range_primary_key_value)
-        return None
+        else:
+            return None
 
     def get_entity_properties(self, label, pk_prop, primary_key_value):
         if self.graph.has_node(primary_key_value):
             return self.graph.nodes[primary_key_value]
-        return None
+        else:
+            return None
 
     def close(self):
-        print("All nodes in the graph:")
+
+        """print("All nodes in the graph:")
         for node, data in self.graph.nodes(data=True):
             print(f"  Node: {node}, Data: {data}")
         
         print("\nAll relationships in the graph:")
         for start, end, data in self.graph.edges(data=True):
-            print(f"  Edge: {start} -> {end}, Data: {data}")
+            print(f"  Edge: {start} -> {end}, Data: {data}")"""
         self.save()
         self.graph.clear()
 
