@@ -4,7 +4,7 @@ from graph.query_agent import QueryAgent
 from graph.update_agent import UpdateAgent
 from graph.query_rewrite_agent import QueryRewriteAgent
 from datetime import date
-
+from colored import cprint
 
 class KnowledgeGraph:
     """
@@ -12,7 +12,7 @@ class KnowledgeGraph:
     and querying entities and relationships based on a provided ontology.
     """
 
-    def __init__(self, ontology: KnowledgeOntology):
+    def __init__(self, ontology: KnowledgeOntology, use_neo4j: bool = False):
         """
         Initializes the KnowledgeGraph, connects to the Neo4j database, and sets up
         the query and update agents with tools derived from the ontology.
@@ -21,7 +21,7 @@ class KnowledgeGraph:
             ontology (KnowledgeOntology): The ontology defining the graph's structure.
         """
         self.ontology = ontology
-        self.graph_database = Neo4jGraphDatabase()
+        self.graph_database = NetworkxGraphDatabase() if not use_neo4j else Neo4jGraphDatabase()
         self.get_tools = self.ontology.get_get_tools(self.graph_database.get_all_entities_by_label, 
             self.graph_database.get_entity_properties, self.graph_database.get_relationship_properties, self.graph_database.get_relationship_entities)
         self.add_or_update_tools = self.ontology.get_add_or_update_tools(self.graph_database.add_or_update_entity, self.graph_database.add_relationship)        
@@ -29,11 +29,12 @@ class KnowledgeGraph:
         self.update_agent = UpdateAgent(self.ontology,self.add_or_update_tools)
         self.rewrite_agent = QueryRewriteAgent(self.ontology,[])
         self.class_entity_pairs = {}
+        cprint(f"KnowledgeGraph initialized", "green")
 
     def get_class_entity_pairs(self):
         for entity_class in self.ontology.entity_classes:
             self.class_entity_pairs[entity_class.entity_class_name] = []
-            entities = self.get_all_entities_by_label(entity_class.entity_class_name)
+            entities = self.graph_database.get_all_entities_by_label(entity_class.entity_class_name)
             for entity in entities:
                 self.class_entity_pairs[entity_class.entity_class_name].append(entity[entity_class.primary_key_prop.property_name])
             
