@@ -21,7 +21,7 @@ class UpdateAgent:
             """),
             show_tool_calls=True,
             markdown=True,
-            debug_mode=True,
+            debug_mode=False,
             )
 
     def update(self, knowledge: str):
